#
# spec file for package kmozillahelper
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# this is needed to match this package with the main package without the main package
# having a hard requirement on this package
%define helper_version 6
Name:           kmozillahelper
Version:        5.0.6
Release:        1.1
Summary:        Helper for KDE Firefox Integration
License:        MIT
Group:          System/GUI/KDE
URL:            https://github.com/openSUSE/kmozillahelper
Source:         https://github.com/openSUSE/kmozillahelper/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  rpm_macro(cmake_kf5)
Requires:       mozilla-kde4-version = %{helper_version}
Supplements:    packageand(MozillaFirefox:plasma5-desktop)
Supplements:    packageand(MozillaThunderbird:plasma5-desktop)
# make sure the package is not installed when there is still
# a user of the old api version
Conflicts:      mozilla-kde4-version < %{helper_version}
# package rename
Provides:       mozilla-xulrunner191-kde4 = %{version}-%{release}
Obsoletes:      mozilla-xulrunner191-kde4 < %{version}-%{release}
# functionality integrated here
Obsoletes:      MozillaFirefox-kde4-addon <= 0.3.0
Provides:       MozillaFirefox-kde4-addon = 0.3.1
Provides:       mozilla-kde4-integration = %{version}
Obsoletes:      mozilla-kde4-integration < %{version}

%description
Package providing integration of Mozilla applications with KDE.

%prep
%setup -q

%build
version=$(grep '#define HELPER_VERSION' main.cpp | cut -d ' ' -f 3)
if test "$version" != %{helper_version}; then
    echo fix the version in the .spec file
    exit 1
fi
%cmake_kf5 -d build
%make_jobs

%install
%kf5_makeinstall -C build

%files
%license LICENSE
%dir %{_prefix}/lib/mozilla
%{_prefix}/lib/mozilla/kmozillahelper
%{_datadir}/knotifications5/kmozillahelper.notifyrc

%changelog
* Thu Jan  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire rpm_macro(cmake_kf5): we call cmake_kf5 to build and
  thus need to ensure the macro to be known.
- Add extra-cmake-modules BuildRequires: fix build after recent KDE
  Frameworks update.
* Sat Oct 17 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.0.6:
  * Exclude kmozillahelper from session management (boo#1176852)
* Fri Jul 17 2020 Tom Warnke <tom@toromtomtom.com>
- Supplement not only MozillaFirefox, but also MozillaThunderbird
* Thu Aug  1 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.0.5:
  * Recognize if started from Thunderbird
* Thu Jul 18 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.0.4:
  * Cache helper protocols (boo#1037806)
  * Use new style connect
  * Don't use deprecated KRun:runUrl without flags, use with flags
* Sat Dec  8 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.0.3:
  * Improve HiDPI support
- Add %%license
* Fri Jan 19 2018 fabian@ritter-vogt.de
- Update to 5.0.2:
  * Workaround for file dialogs failing to deliver the result
    under some circumstances
* Sat Feb 11 2017 fabian@ritter-vogt.de
- Update to 5.0.1:
  * Fix crash with missing filetype description gh#kmozillahelper/9
  * Fix excessive CPU use in some cases
* Wed Feb  8 2017 fabian@ritter-vogt.de
- Bump version to 5.0.0, ready for factory submission
* Tue Jan 31 2017 fabian@ritter-vogt.de
- Update to 4.9.15 to fix the default directory selected in
  file dialogs
* Mon Jan 30 2017 fabian@ritter-vogt.de
- Update to 4.9.14 to fix 100%% CPU consumption after quitting firefox
  and also handle fake mimetypes for protocols (x-scheme-handler/...)
* Sat Jan 28 2017 fabian@ritter-vogt.de
- Update to 4.9.13 to disallow simultaneous commands from multiple
  firefox windows
* Tue Jan 24 2017 fabian@ritter-vogt.de
- Update to 4.9.12 to implement setting dialogs modal for firefox
* Fri Jan 20 2017 fabian@ritter-vogt.de
- Update to 4.9.11 to fix default file dialog location and filename
* Fri Jan 20 2017 fabian@ritter-vogt.de
- Update to 4.9.10 to fix build with Leap 42.1
* Mon Jan 16 2017 fabian@ritter-vogt.de
- Add initial package
